@@ -12,7 +12,7 @@ from transformers import T5ForConditionalGeneration, T5Tokenizer
 
 
 
-class TQA():
+class Machine():
 	def ContextGenQA(self,question, context, model_path, tokenizer_model):
 		"""Сгенерировать ответ моделью для заданных вопроса и контекста, с заданным токенайзером
 			
